@@ -12,9 +12,10 @@ ID_STRING = u"id_string"
 SMS_KEYWORD = u"sms_keyword"
 SMS_ID = u"sms_id"
 SMS_SEPARATOR = u"sms_separator"
-SMS_ALLOW_MEDIAS = u"sms_allow_medias"
+SMS_ALLOW_MEDIA = u"sms_allow_media"
 SMS_DATE_FORMAT = u"sms_date_format"
 SMS_DATETIME_FORMAT = u"sms_datetime_format"
+SMS_RESPONSE = u"sms_response"
 VERSION = u"version"
 PUBLIC_KEY = u"public_key"
 SUBMISSION_URL = u"submission_url"
