@@ -46,7 +46,7 @@ settings_header_aliases = {
     u"form_id": constants.ID_STRING,
     u"sms_keyword": constants.SMS_KEYWORD,
     u"sms_separator": constants.SMS_SEPARATOR,
-    u"sms_allow_medias": constants.SMS_ALLOW_MEDIAS,
+    u"sms_allow_media": constants.SMS_ALLOW_MEDIA,
     u"sms_date_format": constants.SMS_DATE_FORMAT,
     u"sms_datetime_format": constants.SMS_DATETIME_FORMAT,
     u"set form id": constants.ID_STRING,
@@ -60,9 +60,10 @@ survey_header_aliases = {
     u"Name": u"name",
     u"SMS ID": constants.SMS_ID,
     u"SMS Sepatator": constants.SMS_SEPARATOR,
-    u"SMS Allow Medias": constants.SMS_ALLOW_MEDIAS,
+    u"SMS Allow Media": constants.SMS_ALLOW_MEDIA,
     u"SMS Date Format": constants.SMS_DATE_FORMAT,
     u"SMS DateTime Format": constants.SMS_DATETIME_FORMAT,
+    u"SMS Response": constants.SMS_RESPONSE,
     u"Type": u"type",
     u"List_name": u"list_name",
     u"repeat_count": u"jr:count",
